var NAVTREEINDEX4 =
{
"group__API__Data__Interfaces.html#ga3a3cf303a3e3be144aab7abdf587c900":[57,5,66],
"group__API__Data__Interfaces.html#ga3aa3b2a467688f95fe6dd3355112dfc6":[57,5,188],
"group__API__Data__Interfaces.html#ga3bb8d6c4169e578b219849148eece329":[57,5,43],
"group__API__Data__Interfaces.html#ga3ef8a3c5b91f3d3b048a4e5f51a4c4c0":[57,5,47],
"group__API__Data__Interfaces.html#ga3f0c5626c9d5f7addb417834d6be7861":[57,5,48],
"group__API__Data__Interfaces.html#ga40384636cdeec2bdeeccf5a50a081c3b":[57,5,170],
"group__API__Data__Interfaces.html#ga40f2d8762bc1060e939eecae75f9be08":[57,5,198],
"group__API__Data__Interfaces.html#ga40f5b44c5d9bfd39f2f305aa32a25787":[57,5,212],
"group__API__Data__Interfaces.html#ga4248716bc322e1628b86365d7b9a8822":[57,5,183],
"group__API__Data__Interfaces.html#ga451ea6b212d0442b2bda2937c08968f5":[57,5,94],
"group__API__Data__Interfaces.html#ga461a1d65e0f4559dacbc1ba77eafbb2b":[57,5,147],
"group__API__Data__Interfaces.html#ga47cea6fc5b88aaa359066e8192fafe95":[57,5,162],
"group__API__Data__Interfaces.html#ga487b41c917f6317221d85ab626afd353":[57,5,130],
"group__API__Data__Interfaces.html#ga4a52c2c736f00d5694fd12f94468d161":[57,5,60],
"group__API__Data__Interfaces.html#ga4d59be187bd3b97b656ab0e049f50fb2":[57,5,120],
"group__API__Data__Interfaces.html#ga4f137b139435d4cddcd15704fe46cbbd":[57,5,199],
"group__API__Data__Interfaces.html#ga4fecd59ebb415d8e64749ab6d0e41870":[57,5,46],
"group__API__Data__Interfaces.html#ga53b17bba653978ee769ec4a2a3bdae68":[57,5,133],
"group__API__Data__Interfaces.html#ga540f980b1c4bee16c78d84097a8b07f9":[57,5,193],
"group__API__Data__Interfaces.html#ga54dca826f319369d94c4cd6be0eb4828":[57,5,208],
"group__API__Data__Interfaces.html#ga550d6222ff484201dbd3d39bb7baeb7d":[57,5,33],
"group__API__Data__Interfaces.html#ga567d2e3780dabc30269af5e54fe20660":[57,5,78],
"group__API__Data__Interfaces.html#ga56d6ae5fe9283bfb77e13f07c2513184":[57,5,24],
"group__API__Data__Interfaces.html#ga588a7cbb105708b588e5fe008fbb9e9c":[57,5,91],
"group__API__Data__Interfaces.html#ga59929ae2575a893d320f356c4f893453":[57,5,126],
"group__API__Data__Interfaces.html#ga59cbe4cadbe314b73807dc20363db5b9":[57,5,93],
"group__API__Data__Interfaces.html#ga5c4dfa96a4ffa7be08e22a9dc20484e4":[57,5,149],
"group__API__Data__Interfaces.html#ga5ebc1643dba047e9a628cf190df03169":[57,5,134],
"group__API__Data__Interfaces.html#ga6062186a44105e3024a62d2077a32ffe":[57,5,165],
"group__API__Data__Interfaces.html#ga61d4cba212074e157a4236f9e03ffce9":[57,5,54],
"group__API__Data__Interfaces.html#ga63c26124d04338849795d76f291a3739":[57,5,100],
"group__API__Data__Interfaces.html#ga64e03caa2ee034b7e86320a21fcf82ee":[57,5,58],
"group__API__Data__Interfaces.html#ga66106513707ed71b8849b1c1bbb3df75":[57,5,196],
"group__API__Data__Interfaces.html#ga66508648e621019be00d86832d66f278":[57,5,160],
"group__API__Data__Interfaces.html#ga66b9bd15585432fa97499d37aaf13351":[57,5,79],
"group__API__Data__Interfaces.html#ga66df9aff4ea14be546df745f17365568":[57,5,161],
"group__API__Data__Interfaces.html#ga6711060d6f12245db58b245912e92005":[57,5,176],
"group__API__Data__Interfaces.html#ga69dd5090534b513a374089627254f73c":[57,5,81],
"group__API__Data__Interfaces.html#ga6d0c09ee7cd90ac23454ef2040a4bc25":[57,5,211],
"group__API__Data__Interfaces.html#ga6f28e1a774923108005760426cf8da5b":[57,5,18],
"group__API__Data__Interfaces.html#ga6f64340041ca2277f071aebd9bd3ea7b":[57,5,21],
"group__API__Data__Interfaces.html#ga71795d4368a064e25c1366a168429529":[57,5,131],
"group__API__Data__Interfaces.html#ga720fcf673578ec23e583b5f674626847":[57,5,148],
"group__API__Data__Interfaces.html#ga72c9db50152ed5bf9f18ad3a355c5376":[57,5,197],
"group__API__Data__Interfaces.html#ga748def68db84b3cb9da305b0e3f7c935":[57,5,71],
"group__API__Data__Interfaces.html#ga75d457d6e5181fff12d031d2a2c6db28":[57,5,167],
"group__API__Data__Interfaces.html#ga78a31ef2148b8439a2c0e897d9179b84":[57,5,201],
"group__API__Data__Interfaces.html#ga7af8e4f90b557fefaa09f40a930efd74":[57,5,128],
"group__API__Data__Interfaces.html#ga7b1f8a896527eb5d667b3e6ccf0ce7bb":[57,5,88],
"group__API__Data__Interfaces.html#ga7c5c5fe50717bae757862f58053f97a5":[57,5,67],
"group__API__Data__Interfaces.html#ga7cc322b2f03830ec7afbb58b7416a283":[57,5,65],
"group__API__Data__Interfaces.html#ga7d44b8a0594932a8cece13e1cc9932bb":[57,5,72],
"group__API__Data__Interfaces.html#ga7e3ef9efbc7a65adad27f9ac27493493":[57,5,139],
"group__API__Data__Interfaces.html#ga7ea069447f11e836d7b709c97d90b570":[57,5,108],
"group__API__Data__Interfaces.html#ga81160c064d381e20cf874ec053e167f9":[57,5,166],
"group__API__Data__Interfaces.html#ga81b34820b1a410d218ad08528c0317f6":[57,5,157],
"group__API__Data__Interfaces.html#ga821cbbf32e68e9af90dcbeb81b9c7034":[57,5,104],
"group__API__Data__Interfaces.html#ga82eea89e2f23a9fdc1f34c03db68a97b":[57,5,86],
"group__API__Data__Interfaces.html#ga833b734aa76cdee89245cb0710793cf9":[57,5,144],
"group__API__Data__Interfaces.html#ga83ba12ab43444d61f4966dc76aa160d6":[57,5,85],
"group__API__Data__Interfaces.html#ga84a3cc04ef603ab17af6d14f23c6ca00":[57,5,109],
"group__API__Data__Interfaces.html#ga8599a8f318fcadbafcc55f9c568678f1":[57,5,156],
"group__API__Data__Interfaces.html#ga86956bce305447697cb9346bee692b24":[57,5,214],
"group__API__Data__Interfaces.html#ga86b64dc68625997cf3c0bb9eae3ee68a":[57,5,75],
"group__API__Data__Interfaces.html#ga87725438ebaccd40d8b1b90e17b46247":[57,5,39],
"group__API__Data__Interfaces.html#ga88d8275866e6f3f430d01e5909cc17f7":[57,5,168],
"group__API__Data__Interfaces.html#ga8a4c1ddb71e09437717e298c3e2c39f9":[57,5,204],
"group__API__Data__Interfaces.html#ga8aa19dcac39f053949c1bb1b4f5fad1d":[57,5,155],
"group__API__Data__Interfaces.html#ga8c04948b40dc3902e9b3de7a84383381":[57,5,206],
"group__API__Data__Interfaces.html#ga8c40de57e43f28beac889b34d0bc69e4":[57,5,55],
"group__API__Data__Interfaces.html#ga8fa1c7e18fa7c621ec68fc5aa32ef181":[57,5,64],
"group__API__Data__Interfaces.html#ga9037815eabc726906d66140b62c03b9b":[57,5,50],
"group__API__Data__Interfaces.html#ga91461bface98435f7e90d515c4aa04cb":[57,5,23],
"group__API__Data__Interfaces.html#ga9263fae0971cb00a9f9108a4a4b1e285":[57,5,49],
"group__API__Data__Interfaces.html#ga9294121fe81a39b6b5e74e8e66bac3e0":[57,5,153],
"group__API__Data__Interfaces.html#ga95f3f5141265f8a78f8b5802be7ea20c":[57,5,22],
"group__API__Data__Interfaces.html#ga9719eab3a5e9fbaad2837b4a985a3a14":[57,5,106],
"group__API__Data__Interfaces.html#ga97859bcb7bc60911362087eefc9249ed":[57,5,209],
"group__API__Data__Interfaces.html#ga97c7b78c97576eb44741bdd7e2183fa7":[57,5,121],
"group__API__Data__Interfaces.html#ga988036ae1f9385832c2988064a4f27af":[57,5,192],
"group__API__Data__Interfaces.html#ga9d14e3576605217f1a160a710fad8178":[57,5,152],
"group__API__Data__Interfaces.html#ga9dc1bbf7a41070a6fcf82e728cae1542":[57,5,77],
"group__API__Data__Interfaces.html#ga9f6457e4a7e558101dd6ad64076a6a99":[57,5,150],
"group__API__Data__Interfaces.html#gaa093608060a222a89fff01130e9c5c64":[57,5,154],
"group__API__Data__Interfaces.html#gaa15cff8f1148e572348095ac5a2ab421":[57,5,32],
"group__API__Data__Interfaces.html#gaa1d6124d3f84336020897d1df1b1cc50":[57,5,163],
"group__API__Data__Interfaces.html#gaa23416a6d049b276fe57b19e069b68b3":[57,5,62],
"group__API__Data__Interfaces.html#gaa29d5f4bd11fce82cd9a01b0e860bf75":[57,5,216],
"group__API__Data__Interfaces.html#gaa2f2140147f15e7b9eec1443690e357c":[57,5,107],
"group__API__Data__Interfaces.html#gaa35025b4b6126c3f22232cea8915cdad":[57,5,68],
"group__API__Data__Interfaces.html#gaa46eb27abc7439c03776d68062f029d4":[57,5,84],
"group__API__Data__Interfaces.html#gaa7a81bad81376cc0f7b8162a4d8dbacd":[57,5,135],
"group__API__Data__Interfaces.html#gaac406e853e677b31a57f2d54263d2602":[57,5,53],
"group__API__Data__Interfaces.html#gaadbd0557a0ca2178a2ebf7673319f53c":[57,5,92],
"group__API__Data__Interfaces.html#gaaeff5c191edc5f3df8ba1a319acd0af9":[57,5,35],
"group__API__Data__Interfaces.html#gab1c57c537a980a2de5e595b2f6204772":[57,5,27],
"group__API__Data__Interfaces.html#gab2bf7713cad5570775bdf4efec79502d":[57,5,136],
"group__API__Data__Interfaces.html#gab316b2febb2b5fb92e83bbaab780f046":[57,5,40],
"group__API__Data__Interfaces.html#gab328b8e0b234147ebe36ceb8e7a55b0a":[57,5,202],
"group__API__Data__Interfaces.html#gab517790a521d1434d9f52de97091f493":[57,5,177],
"group__API__Data__Interfaces.html#gab5666e2f9f46e4aebe367983347384de":[57,5,98],
"group__API__Data__Interfaces.html#gab59c3b606776bdc54f6ccf3f1db4bf38":[57,5,205],
"group__API__Data__Interfaces.html#gab6e12b04b231773f2eff496f57d29ee8":[57,5,114],
"group__API__Data__Interfaces.html#gab7746e58c367202ad0bc8a2decb1bed8":[57,5,178],
"group__API__Data__Interfaces.html#gab7b07d0d2a253e02e1b2d2260cc3fa94":[57,5,76],
"group__API__Data__Interfaces.html#gab7f9484602aeef560cc2e5904e3b2cff":[57,5,194],
"group__API__Data__Interfaces.html#gab9110ecfa66b148e770a375566c1c19d":[57,5,74],
"group__API__Data__Interfaces.html#gab915146b6d59fbd8e6d04480511f7945":[57,5,17],
"group__API__Data__Interfaces.html#gab91cbc596a65e6a4322b657c79934269":[57,5,137],
"group__API__Data__Interfaces.html#gabb03b0b367f445b692e37ab3237d877f":[57,5,195],
"group__API__Data__Interfaces.html#gabcce7df711e56cafddfd82f8f5ee794b":[57,5,113],
"group__API__Data__Interfaces.html#gabe33df9aebbeab34a9f4f319bff5d3e2":[57,5,142],
"group__API__Data__Interfaces.html#gac046f5fb0472cada47cd44650194b1c8":[57,5,14],
"group__API__Data__Interfaces.html#gac14cfc52c450c81dd4789a7aace79d3b":[57,5,122],
"group__API__Data__Interfaces.html#gac23356ed31839f1d1c52efccb7a99dd7":[57,5,15],
"group__API__Data__Interfaces.html#gac2fe5221c0ccc0d082e5bc65830e497b":[57,5,41],
"group__API__Data__Interfaces.html#gac5fd11be8dd93ebfbbf344623f3c2014":[57,5,123],
"group__API__Data__Interfaces.html#gac739182a43ec4dd00618d783b1f2a16c":[57,5,26],
"group__API__Data__Interfaces.html#gac778227f8ff624d7f7ea04f1407fcb92":[57,5,143],
"group__API__Data__Interfaces.html#gac77fef789ec34682ba00b38dcc501170":[57,5,31],
"group__API__Data__Interfaces.html#gac7b7e5f3d4d9a1468df3b9b92743a9fd":[57,5,158],
"group__API__Data__Interfaces.html#gacb816db830d6991909a35a8c0e93a843":[57,5,185],
"group__API__Data__Interfaces.html#gacc62f1150a403bb550d3538b2bffea17":[57,5,119],
"group__API__Data__Interfaces.html#gacc7903845cb442f141de2b1d9450fc63":[57,5,179],
"group__API__Data__Interfaces.html#gacd706856652f629563bce3c0bb528ec6":[57,5,182],
"group__API__Data__Interfaces.html#gacd95c31b537322b1d4000a1248b9c425":[57,5,187],
"group__API__Data__Interfaces.html#gacd9e0b5bd06d1b7d88be4e0143be8a68":[57,5,13],
"group__API__Data__Interfaces.html#gacee0a9e166f87b48da1f56e1ae5d988d":[57,5,189],
"group__API__Data__Interfaces.html#gad3c08c06e55e86993fa5cb77dce95095":[57,5,101],
"group__API__Data__Interfaces.html#gad4850366b77ead9f60c6f7e1d1064b22":[57,5,89],
"group__API__Data__Interfaces.html#gad51f09163a11aad56f942ee152b28d13":[57,5,129],
"group__API__Data__Interfaces.html#gad5ffed03f141096fca4e1e2583c84e22":[57,5,200],
"group__API__Data__Interfaces.html#gad6ca41b04e0265671d4bf899dd433c1e":[57,5,115],
"group__API__Data__Interfaces.html#gad7e204d690945cbe5145bc8950078291":[57,5,117],
"group__API__Data__Interfaces.html#gad9407e7339eb6c8e32e598b7c4c85d70":[57,5,20],
"group__API__Data__Interfaces.html#gad99e209fafc3ad5e0c4da0de02e5bda2":[57,5,70],
"group__API__Data__Interfaces.html#gada534736df809f642437792b1acd7af8":[57,5,172],
"group__API__Data__Interfaces.html#gadccf196d01dd9c43e931827a86f886b2":[57,5,63],
"group__API__Data__Interfaces.html#gadcf7063b1cd8d0feed7054e6e4d9d217":[57,5,210],
"group__API__Data__Interfaces.html#gaddd9b273ddf82a320f66946228f12103":[57,5,173],
"group__API__Data__Interfaces.html#gade238eb388cbb34bf9a93643bfa4df83":[57,5,25],
"group__API__Data__Interfaces.html#gadf8eac3f96b6e63911f23165141411df":[57,5,29],
"group__API__Data__Interfaces.html#gae2a4195d99eedac191857c43cd454226":[57,5,141],
"group__API__Data__Interfaces.html#gae3d95a1379358cbd85c663c8462da98c":[57,5,16],
"group__API__Data__Interfaces.html#gae48e867d81c554b199b127cf9bd4f5b2":[57,5,207],
"group__API__Data__Interfaces.html#gae5d1dbf657ce2c4f55bce1ac2f982d6a":[57,5,118],
"group__API__Data__Interfaces.html#gae95b657d947e611060590d506d8e15dc":[57,5,34],
"group__API__Data__Interfaces.html#gaea999f5e67e778ac28c0a8bc1633ff28":[57,5,87],
"group__API__Data__Interfaces.html#gaeb6356075b3f57e8c7aeccc85f076d87":[57,5,103],
"group__API__Data__Interfaces.html#gaebeefdd9980c18575924ed9860315bcf":[57,5,151],
"group__API__Data__Interfaces.html#gaec6ca64cc2c52e319b9b73cc4f753658":[57,5,217],
"group__API__Data__Interfaces.html#gaeeb3ff0360cafe3fc54e16da2d002c5b":[57,5,82],
"group__API__Data__Interfaces.html#gaeed0ab452c0906a650097368bd1c6ba3":[57,5,80],
"group__API__Data__Interfaces.html#gaef6039a7976d3ee6c6916df28a08da1a":[57,5,19],
"group__API__Data__Interfaces.html#gaefbbb2e643662ee4d7c816d91e8e14df":[57,5,99],
"group__API__Data__Interfaces.html#gaf011a057a557a66271ce06e8109c11c4":[57,5,73],
"group__API__Data__Interfaces.html#gaf0937aae4bedeb03e9ebbec36cc1dad6":[57,5,102],
"group__API__Data__Interfaces.html#gaf0fa0d2dc99ab880ccfe12061770dad2":[57,5,38],
"group__API__Data__Interfaces.html#gaf1843d7f93510e6bf53da173eb9dd75e":[57,5,159],
"group__API__Data__Interfaces.html#gaf3bd64a64625f45859f596db3bb9b40a":[57,5,42],
"group__API__Data__Interfaces.html#gaf5938ea67a4a2c4f140ec527698bf850":[57,5,181],
"group__API__Data__Interfaces.html#gaf5ea640f2c977e3ae95a6be9b3be3bee":[57,5,127],
"group__API__Data__Interfaces.html#gaf972d52af628f82488eeea311eadb4f6":[57,5,191],
"group__API__Data__Interfaces.html#gafb92c2538dc629d823221c5dc16bd767":[57,5,190],
"group__API__Data__Interfaces.html#gafd439524218c70b6b4a784fb12824c28":[57,5,215],
"group__API__Data__Interfaces.html#gafd9d133c4d658b777d9800eba79765b3":[57,5,37],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca1020cba73248160933d8f6c901293437":[57,5,107,5],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca264b360136a55f91ae62c48faa02f376":[57,5,107,1],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca40a80154bc81a5eb4eea06771010bba3":[57,5,107,6],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca4c3642251b2ddf957338ef2729de7f5f":[57,5,107,3],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca5a50ee28bfd93b68341e7644f3e810aa":[57,5,107,4],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca65cfc4ac63a449dd5da3c40ae63bb949":[57,5,107,0],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca7b3ec1ca579bfc82a35d282ed69b0300":[57,5,107,10],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca80d5bec40d12c9b05e1331bab739e39f":[57,5,107,9],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357caa0881ef4be5491fcfb7df81b9778a247":[57,5,107,12],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357caa45ce766ad2fe7020e82e462390c7b38":[57,5,107,8],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357cab24c1ea83c1e376895d316a0981bee0c":[57,5,107,7],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357cac55e5bac53f8121d107f4bebf2d26155":[57,5,107,11],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357cacb8ea4adb7ed650338bfe9e69d3e1bb2":[57,5,107,2],
"group__API__Data__Interfaces.html#structstarpu__bcsr__interface":[57,5,10],
"group__API__Data__Interfaces.html#structstarpu__block__interface":[57,5,4],
"group__API__Data__Interfaces.html#structstarpu__coo__interface":[57,5,3],
"group__API__Data__Interfaces.html#structstarpu__csr__interface":[57,5,9],
"group__API__Data__Interfaces.html#structstarpu__data__copy__methods":[57,5,0],
"group__API__Data__Interfaces.html#structstarpu__data__interface__ops":[57,5,1],
"group__API__Data__Interfaces.html#structstarpu__matrix__interface":[57,5,2],
"group__API__Data__Interfaces.html#structstarpu__multiformat__data__interface__ops":[57,5,11],
"group__API__Data__Interfaces.html#structstarpu__multiformat__interface":[57,5,12],
"group__API__Data__Interfaces.html#structstarpu__ndim__interface":[57,5,6],
"group__API__Data__Interfaces.html#structstarpu__tensor__interface":[57,5,5],
"group__API__Data__Interfaces.html#structstarpu__variable__interface":[57,5,8],
"group__API__Data__Interfaces.html#structstarpu__vector__interface":[57,5,7],
"group__API__Data__Management.html":[57,4],
"group__API__Data__Management.html#ga00223a2f0608eb7893e87119937931d3":[57,4,58],
"group__API__Data__Management.html#ga06b01fdf769f8f2eb222ecde42afbc81":[57,4,17],
"group__API__Data__Management.html#ga07d895064336867923716b7c690c077d":[57,4,14],
"group__API__Data__Management.html#ga10d43386322955cba25889cf9b88b706":[57,4,48],
"group__API__Data__Management.html#ga1f5ba1c1cfefc1f81a4095cf3c213e54":[57,4,53],
"group__API__Data__Management.html#ga1fb3a1ff8622747d653d1b5f41bc41db":[57,4,5],
"group__API__Data__Management.html#ga23ad7e71f5e785d80c55cdf292c34ea8":[57,4,15],
"group__API__Data__Management.html#ga273df19e4cad1c05ec5df697bcec4444":[57,4,45],
"group__API__Data__Management.html#ga2ae876d62ebaf6e402c85991c912f21e":[57,4,55],
"group__API__Data__Management.html#ga2b9b64ac9a650d8c8942b4227e6fce75":[57,4,2],
"group__API__Data__Management.html#ga337cf01e2a0ccc1c3cc2ea27d5bdf131":[57,4,34],
"group__API__Data__Management.html#ga358aba7459b7f99a6dbaa189ce57b925":[57,4,21],
"group__API__Data__Management.html#ga3b2ca6406b5839062346200123551638":[57,4,20],
"group__API__Data__Management.html#ga4e82fe020ec010bcacb6aee16021607c":[57,4,16],
"group__API__Data__Management.html#ga4fa34753bff1d29c20f0a0e361020b4e":[57,4,13],
"group__API__Data__Management.html#ga5458fc0ffdc4b6bae960520f5f599ae5":[57,4,40],
"group__API__Data__Management.html#ga57687b811ced00dbfc35af73164a72aa":[57,4,37],
"group__API__Data__Management.html#ga586146498466b60d6b81145dfaeb8948":[57,4,11],
"group__API__Data__Management.html#ga5b95764e9545fc367cb995950e82f449":[57,4,29],
"group__API__Data__Management.html#ga5fd09305716ce9d3a5a9fd2df6bc7792":[57,4,60],
"group__API__Data__Management.html#ga690e27502b042cbc6969c5f3c5771a84":[57,4,25],
"group__API__Data__Management.html#ga6e0e15426e75b43f7b44e3f3a38c01f1":[57,4,51],
"group__API__Data__Management.html#ga70ee8a92cbb3935ec3ca0d40f443f860":[57,4,23],
"group__API__Data__Management.html#ga78ffeb2e27e87bfc118e7fe2157ae4c2":[57,4,27],
"group__API__Data__Management.html#ga7badde35fa2205201fad73fd851133fa":[57,4,30],
"group__API__Data__Management.html#ga80778d87c0e2181096124f03bebe53cd":[57,4,6],
"group__API__Data__Management.html#ga80b7284bb413ae7acac0fe83268c10f1":[57,4,50],
"group__API__Data__Management.html#ga8771ea54051655e68ed7a95b4b831fc7":[57,4,32],
"group__API__Data__Management.html#ga88a1a866445372adf0a07a349ecc7a5a":[57,4,10],
"group__API__Data__Management.html#ga8b98dee994de7c323a81ac6e573e5693":[57,4,49],
"group__API__Data__Management.html#ga8bcfd56807cf9436eca71c6e3ade2dab":[57,4,41],
"group__API__Data__Management.html#ga8db878885ebbee4729d8aed6a0479262":[57,4,22],
"group__API__Data__Management.html#ga916df5cfe739f832d51bd66012b500cb":[57,4,31],
"group__API__Data__Management.html#ga982a42a7afc942863de2349bc8f201a9":[57,4,26],
"group__API__Data__Management.html#ga9a6122bae224d714383ae775434cdce3":[57,4,52],
"group__API__Data__Management.html#ga9cbc51da2f2b7025c534d6862866bf81":[57,4,33],
"group__API__Data__Management.html#ga9ce32e79b2f07fb474b6ae10006abb1f":[57,4,36],
"group__API__Data__Management.html#ga9d4db8e3a8a6ea4c6757a455849e1504":[57,4,8],
"group__API__Data__Management.html#gaa1f95d17759711f7703bf02820e2e49b":[57,4,12],
"group__API__Data__Management.html#gaa62248a017ee1494ca399789d7687aac":[57,4,61],
"group__API__Data__Management.html#gaa9084f77b596022f0635b5e326bc450e":[57,4,7],
"group__API__Data__Management.html#gaaaaa769d715f01b5636a837fd86c9671":[57,4,59],
"group__API__Data__Management.html#gab3f057daac283b3b7351b03b0d574493":[57,4,43],
"group__API__Data__Management.html#gab9497db9ea78dafa7ba0a2b99a7fc0f2":[57,4,9],
"group__API__Data__Management.html#gab97817681d85c64d7d84e4b9a88c4811":[57,4,54],
"group__API__Data__Management.html#gabd61bf0201af91a3d4e6501ebdf8e851":[57,4,4],
"group__API__Data__Management.html#gac561fd637be17b74f0456106dc25f5d1":[57,4,35],
"group__API__Data__Management.html#gac83c13a23641632701971e2d48f7c5fa":[57,4,56],
"group__API__Data__Management.html#gac88c5f320d2c900923b7934d9a733104":[57,4,46],
"group__API__Data__Management.html#gaceb23371963b642f4155ffa728f3bf03":[57,4,1],
"group__API__Data__Management.html#gad5a24f94d0aa2bbfab8957c3dd13949a":[57,4,39],
"group__API__Data__Management.html#gad6bed33cdb76ef504efcdf05e5788076":[57,4,3],
"group__API__Data__Management.html#gadc145017bafa2948109c624715de77a2":[57,4,28],
"group__API__Data__Management.html#gae53e7b21c7426c9845a1046cfe5becce":[57,4,44],
"group__API__Data__Management.html#gae5f926615eaa6e318ee0fc4ac0be9e3e":[57,4,38],
"group__API__Data__Management.html#gae6eb535cf9bf46a7ef9ad2d845c675a2":[57,4,19],
"group__API__Data__Management.html#gaedc8031c1b437d35232cd1700d83d472":[57,4,18]
};
